@@ -8,8 +8,8 @@ from psutil import process_iter
 from uno import createUnoStruct
 from unogenerator.reusing.listdict_functions import listdict_min
 
-__version__ = '0.9.0'
-__versiondatetime__=datetime(2021, 10, 28, 22, 8)
+__version__ = '0.10.0'
+__versiondatetime__=datetime(2021, 11, 1, 10, 11)
 __versiondate__=__versiondatetime__.date()
 
 try:
@@ -446,8 +446,8 @@ def get_from_process_info(cpu_percentage=False):
                 if  'file:///tmp/unogenerator'  in ' '.join(p.info['cmdline']):
                     d["port"]=int(p.info['cmdline'][1][-4:])
                     d["pid"]=p.pid
-                    vms=p.memory_info().vms
-                    d["mem"]=vms
+                    d["mem"]=p.memory_info().rss
+                    d["cpu_number"]=p.cpu_num()
                     if cpu_percentage is True:
                         d["cpu_percentage"]=p.cpu_percent(interval=0.01)
                         d["object"]=p
