@@ -57,7 +57,6 @@ def main(arguments=None):
     if args.create==True:
         start=datetime.now()
         futures=[]
-        
         with ProcessPoolExecutor(max_workers=cpu_count()+1) as executor:
             for language in ['es', 'en']:
                 futures.append(executor.submit(demo_ods_standard, language))
@@ -219,7 +218,6 @@ def demo_ods_standard(language, port=2002, suffix="",):
     lod.append(OrderedDict({"Singer": "Roy Orbison",  "Songs": 100,  "Albums": 20 }))
     helper_list_of_ordereddicts_with_totals(doc, "A36",  lod, columns_header=1)
 
-    doc.removeSheet(0)
     doc.save(f"unogenerator_example_{language}{suffix}.ods")
     doc.export_xlsx(f"unogenerator_example_{language}{suffix}.xlsx")
     doc.export_pdf(f"unogenerator_example_{language}{suffix}.pdf")
@@ -403,6 +401,8 @@ doc.close()"""    , "Code")
     doc.addParagraph(_("This paragraph was set after a page break with Landscape style."), "Standard")
     
     
+#    doc.find_and_delete_until_the_end_of_document("This paragraph was set after replacement.")
+    
     
     doc.save(f"unogenerator_documentation_{language}{suffix}.odt")
     doc.export_docx(f"unogenerator_documentation_{language}{suffix}.docx")
